@@ -4,12 +4,12 @@ from .commands import make_project
 from .commands import remove_poetry
 from .commands import work
 from .commands import write_env_file
-from .commands import setup_postgres
+from .config import APP_NAME
 
 
 def get_app():
     app = typer.Typer(
-        name="fuzzy-couscous",
+        name=APP_NAME,
         short_help="Initialize a new django project using the fuzzy-couscous project template.",
         help="""This is a wrapper around the django-admin startproject  command using my custom project template at
         https://github.com/Tobi-De/fuzzy-couscous. This cli also includes some additional commands to make setting up
@@ -20,7 +20,6 @@ def get_app():
     app.command(name="work")(work)
     app.command(name="remove-poetry")(remove_poetry)
     app.command(name="write-env")(write_env_file)
-    app.command(name="setup-pg")(setup_postgres)
     return app
 
 
